==> zio-aws-schemas_2.13-5.17.121.3-sources.jar: zio/aws/schemas/model/StopDiscovererRequest.scala <==
package zio.aws.schemas.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.schemas.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class StopDiscovererRequest(discovererId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.schemas.model.StopDiscovererRequest = {
    import StopDiscovererRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.schemas.model.StopDiscovererRequest
      .builder()
      .discovererId(__string.unwrap(discovererId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.schemas.model.StopDiscovererRequest.ReadOnly =
    zio.aws.schemas.model.StopDiscovererRequest.wrap(buildAwsValue())
}
object StopDiscovererRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.schemas.model.StopDiscovererRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.schemas.model.StopDiscovererRequest =
      zio.aws.schemas.model.StopDiscovererRequest(discovererId)
    def discovererId: __string
    def getDiscovererId: ZIO[Any, Nothing, __string] = ZIO.succeed(discovererId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.schemas.model.StopDiscovererRequest
  ) extends zio.aws.schemas.model.StopDiscovererRequest.ReadOnly {
    override val discovererId: __string =
      zio.aws.schemas.model.primitives.__string(impl.discovererId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.schemas.model.StopDiscovererRequest
  ): zio.aws.schemas.model.StopDiscovererRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-schemas_2.13-5.17.295.2-sources.jar: zio/aws/schemas/model/StopDiscovererRequest.scala <==
package zio.aws.schemas.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.schemas.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class StopDiscovererRequest(discovererId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.schemas.model.StopDiscovererRequest = {
    import StopDiscovererRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.schemas.model.StopDiscovererRequest
      .builder()
      .discovererId(discovererId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.schemas.model.StopDiscovererRequest.ReadOnly =
    zio.aws.schemas.model.StopDiscovererRequest.wrap(buildAwsValue())
}
object StopDiscovererRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.schemas.model.StopDiscovererRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.schemas.model.StopDiscovererRequest =
      zio.aws.schemas.model.StopDiscovererRequest(discovererId)
    def discovererId: __string
    def getDiscovererId: ZIO[Any, Nothing, __string] = ZIO.succeed(discovererId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.schemas.model.StopDiscovererRequest
  ) extends zio.aws.schemas.model.StopDiscovererRequest.ReadOnly {
    override val discovererId: __string = impl.discovererId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.schemas.model.StopDiscovererRequest
  ): zio.aws.schemas.model.StopDiscovererRequest.ReadOnly = new Wrapper(impl)
}
